@@ -11,7 +11,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
-our $VERSION = '0.3';
+our $VERSION = '0.4';
 
 my $dateRegex = '\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}Z';
 
@@ -62,6 +62,9 @@ an item
         'Track ID' => '73',
         'Name' => 'Josie',
         'Artist' => 'blink-182',
+        'Album Artist' => 'blink-182',
+        'Composer' => 'blink-182',
+        'Album' => 'Dude Ranch',
         'Genre' => 'Pop Punk',
         'Kind' => 'MPEG audio file',
         'Size' => 31337,
@@ -92,6 +95,9 @@ sub new {
         'Track ID' => undef,
         'Name' => undef,
         'Artist' => undef,
+        'Album Artist' => undef,
+        'Composer' => undef,
+        'Album' => undef,
         'Genre' => undef,
         'Kind' => undef,
         'Size' => undef,
@@ -121,6 +127,12 @@ sub new {
         name( $self, $params{'Name'} );
     } if ( exists( $params{'Artist'} ) ) {
         artist( $self, $params{'Artist'} );
+    } if ( exists( $params{'Album Artist'} ) ) {
+        albumArtist( $self, $params{'Album Artist'} );
+    } if ( exists( $params{'Composer'} ) ) {
+        composer( $self, $params{'Composer'} );
+    } if ( exists( $params{'Album'} ) ) {
+        album( $self, $params{'Album'} );
     } if ( exists( $params{'Genre'} ) ) {
         genre( $self, $params{'Genre'} );
     } if ( exists( $params{'Kind'} ) ) {
@@ -216,6 +228,60 @@ sub artist {
     return $self->{'Artist'};
 } #artist
 
+=item albumArtist( $albumArtist )
+
+Get/set the Album Artist attribute for this item.
+
+=cut
+
+sub albumArtist {
+    my $self = shift;
+
+    if (@_) {
+        my $albumArtist = shift;
+        return carp "$albumArtist isn't a valid Album Artist" unless ($albumArtist =~ /.*/);
+        $self->{'Album Artist'} = $albumArtist;
+    }
+
+    return $self->{'Album Artist'};
+} #albumArtist
+
+=item composer( $composer )
+
+Get/set the Composer attribute for this item.
+
+=cut
+
+sub composer {
+    my $self = shift;
+
+    if (@_) {
+        my $composer = shift;
+        return carp "$composer isn't a valid Composer" unless ($composer =~ /.*/);
+        $self->{'Composer'} = $composer;
+    }
+
+    return $self->{'Composer'};
+} #composer
+
+=item album( $album )
+
+Get/set the Album attribute for this item.
+
+=cut
+
+sub album {
+    my $self = shift;
+
+    if (@_) {
+        my $album = shift;
+        return carp "$album isn't a valid Album" unless ($album =~ /.*/);
+        $self->{'Album'} = $album;
+    }
+
+    return $self->{'Album'};
+} #album
+
 =item genre( $genre )
 
 Get/set the Genre attribute for this item.
@@ -568,8 +634,8 @@ Drew Stephens <drew@dinomite.net>, http://dinomite.net
 
 =head1 SVN INFO
 
-$Revision: 59 $
-$Date: 2009-01-04 22:59:26 -0800 (Sun, 04 Jan 2009) $
+$Revision: 61 $
+$Date: 2009-04-27 22:40:34 -0700 (Mon, 27 Apr 2009) $
 $Author: drewgstephens $
 
 =head1 COPYRIGHT AND LICENSE
